@@ -781,9 +781,6 @@ void rrdhost_free___while_having_rrd_wrlock(RRDHOST *host) {
     pulse_host_status(host, PULSE_HOST_STATUS_DELETED, 0);
     __atomic_sub_fetch(&netdata_buffers_statistics.rrdhost_allocations_size, sizeof(RRDHOST), __ATOMIC_RELAXED);
 
-    if (host == localhost)
-        health_plugin_destroy();
-
     freez(host->cache_dir);
     rrdhost_stream_parents_free(host, false);
     simple_pattern_free(host->stream.snd.charts_matching);
