@@ -347,8 +347,7 @@ func (m *Manager) dyncfgConfigRestart(fn functions.Function) {
 		m.dyncfgJobStatus(ecfg.cfg, ecfg.status)
 		return
 	case dyncfgRunning:
-		m.FileStatus.Remove(ecfg.cfg)
-		m.FileLock.Unlock(ecfg.cfg.FullName())
+		m.fileStatus.remove(ecfg.cfg)
 		m.stopRunningJob(ecfg.cfg.FullName())
 	default:
 	}
@@ -363,18 +362,10 @@ func (m *Manager) dyncfgConfigRestart(fn functions.Function) {
 		return
 	}
 
-	if ok, err := m.FileLock.Lock(ecfg.cfg.FullName()); !ok && err == nil {
-		job.Cleanup()
-		ecfg.status = dyncfgFailed
-		m.dyncfgRespf(fn, 500, "Job restart failed: cannot filelock.")
-		m.dyncfgJobStatus(ecfg.cfg, ecfg.status)
-		return
-	}
-
 	ecfg.status = dyncfgRunning
 
 	if isDyncfg(ecfg.cfg) {
-		m.FileStatus.Save(ecfg.cfg, ecfg.status.String())
+		m.fileStatus.add(ecfg.cfg, ecfg.status.String())
 	}
 	m.startRunningJob(job)
 	m.dyncfgRespf(fn, 200, "")
@@ -451,18 +442,10 @@ func (m *Manager) dyncfgConfigEnable(fn functions.Function) {
 		return
 	}
 
-	if ok, err := m.FileLock.Lock(ecfg.cfg.FullName()); !ok && err == nil {
-		job.Cleanup()
-		ecfg.status = dyncfgFailed
-		m.dyncfgRespf(fn, 500, "Job enable failed: can not filelock.")
-		m.dyncfgJobStatus(ecfg.cfg, ecfg.status)
-		return
-	}
-
 	ecfg.status = dyncfgRunning
 
 	if isDyncfg(ecfg.cfg) {
-		m.FileStatus.Save(ecfg.cfg, ecfg.status.String())
+		m.fileStatus.add(ecfg.cfg, ecfg.status.String())
 	}
 
 	m.startRunningJob(job)
@@ -499,9 +482,8 @@ func (m *Manager) dyncfgConfigDisable(fn functions.Function) {
 	case dyncfgRunning:
 		m.stopRunningJob(ecfg.cfg.FullName())
 		if isDyncfg(ecfg.cfg) {
-			m.FileStatus.Remove(ecfg.cfg)
+			m.fileStatus.remove(ecfg.cfg)
 		}
-		m.FileLock.Unlock(ecfg.cfg.FullName())
 	default:
 	}
 
@@ -601,8 +583,7 @@ func (m *Manager) dyncfgConfigRemove(fn functions.Function) {
 	m.seenConfigs.remove(ecfg.cfg)
 	m.exposedConfigs.remove(ecfg.cfg)
 	m.stopRunningJob(ecfg.cfg.FullName())
-	m.FileLock.Unlock(ecfg.cfg.FullName())
-	m.FileStatus.Remove(ecfg.cfg)
+	m.fileStatus.remove(ecfg.cfg)
 
 	m.dyncfgRespf(fn, 200, "")
 	m.dyncfgJobRemove(ecfg.cfg)
@@ -686,14 +667,6 @@ func (m *Manager) dyncfgConfigUpdate(fn functions.Function) {
 		return
 	}
 
-	if ok, err := m.FileLock.Lock(scfg.cfg.FullName()); !ok && err == nil {
-		job.Cleanup()
-		scfg.status = dyncfgFailed
-		m.dyncfgRespf(fn, 500, "Job update failed: cannot create file lock.")
-		m.dyncfgJobStatus(scfg.cfg, scfg.status)
-		return
-	}
-
 	scfg.status = dyncfgRunning
 	m.startRunningJob(job)
 	m.dyncfgRespf(fn, 200, "")
